;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "rustic" "20250630.1332"
  "Rust development environment."
  '((emacs         "28.2")
    (rust-mode     "1.0.6")
    (dash          "2.13.0")
    (f             "0.18.2")
    (let-alist     "1.0.4")
    (markdown-mode "2.3")
    (project       "0.3.0")
    (s             "1.10.0")
    (spinner       "1.7.3")
    (xterm-color   "1.6"))
  :url "https://github.com/emacs-rustic/rustic"
  :commit "bfff139f260c386f60d581edef6df1a0d109a131"
  :revdesc "bfff139f260c"
  :keywords '("languages"))
